Skip to contents

The function BS12() defines the Birnbaum-Saunders distribution, a two-parameter distribution, for a gamlss.family object to be used in GAMLSS fitting using the function gamlss().

Usage

BS12(mu.link = "log", sigma.link = "log")

Arguments

defines the mu.link, with "log" link as the default for the mu parameter (representing the scale \(\beta\)).

defines the sigma.link, with "log" link as the default for the sigma parameter (representing the shape \(\psi\)).

Value

Returns a gamlss.family object which can be used to fit a BS12 distribution in the gamlss() function.

Details

The Birnbaum-Saunders distribution with parameters mu and sigma (where mu represents \(\beta\) and sigma represents \(\psi\)) has density given by

\(f(x|\mu,\sigma) = \frac{1}{\sqrt{2\pi}} \exp\left( -\frac{\sigma}{2} \left[ \frac{x}{\mu} + \frac{\mu}{x} - 2 \right] \right) \frac{[x+\mu]\sqrt{\sigma}}{2\sqrt{\mu x^3}}\)

for \(x>0\), \(\mu>0\) and \(\sigma>0\). In this parameterization, \(E(X) = \mu + \frac{\mu}{2\sigma}\) and \(Var(X) = \frac{\mu^2}{\sigma} + \frac{5\mu^2}{4\sigma^2}\).

References

Santos-Neto, M., Cysneiros, F. J. A., Leiva, V., & Ahmed, S. E. (2012). On new parameterizations of the Birnbaum-Saunders distribution. Pakistan Journal of Statistics, 28(1), 1-26.

See also

Author

David Villegas Ceballos, david.villegas1@udea.edu.co

Examples

# Example 1
# Generating some random values with
# known mu and sigma
set.seed(12345)
y <- rBS12(n=100, mu=1, sigma=30)

# Fitting the model
require(gamlss)
mod1 <- gamlss(y~1, sigma.fo=~1, family=BS12)
#> GAMLSS-RS iteration 1: Global Deviance = -42.2156 
#> GAMLSS-RS iteration 2: Global Deviance = -42.2157 

# Extracting the fitted values for mu and sigma
# using the inverse link function
exp(coef(mod1, what="mu"))
#> (Intercept) 
#>    1.001539 
exp(coef(mod1, what="sigma"))
#> (Intercept) 
#>     25.8992 

# Example 2
# Generating random values for a regression model

# A function to simulate a data set with Y ~ BS12
gendat <- function(n) {
  x1 <- runif(n)
  x2 <- runif(n)
  mu <- exp(0.5 - 1 * x1)      # Aprox 1
  sigma <- exp(2.2 + 2.4 * x2)   # Aprox 30
  y <- rBS12(n=n, mu=mu, sigma=sigma)
  data.frame(y=y, x1=x1, x2=x2)
}

set.seed(123)
dat <- gendat(n=200)

mod2 <- gamlss(y~x1, sigma.fo=~x2, 
               family=BS12, data=dat)
#> GAMLSS-RS iteration 1: Global Deviance = -108.1624 
#> GAMLSS-RS iteration 2: Global Deviance = -109.0761 
#> GAMLSS-RS iteration 3: Global Deviance = -109.0766 

summary(mod2)
#> Warning: summary: vcov has failed, option qr is used instead
#> ******************************************************************
#> Family:  c("BS12", "Birnbaum-Saunders - Twelfth parameterization") 
#> 
#> Call:  gamlss(formula = y ~ x1, sigma.formula = ~x2, family = BS12,  
#>     data = dat) 
#> 
#> Fitting method: RS() 
#> 
#> ------------------------------------------------------------------
#> Mu link function:  log
#> Mu Coefficients:
#>             Estimate Std. Error t value Pr(>|t|)    
#> (Intercept)   0.5157     0.0228   22.62   <2e-16 ***
#> x1           -1.0409     0.0411  -25.33   <2e-16 ***
#> ---
#> Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#> 
#> ------------------------------------------------------------------
#> Sigma link function:  log
#> Sigma Coefficients:
#>             Estimate Std. Error t value Pr(>|t|)    
#> (Intercept)   2.0467     0.2020  10.132  < 2e-16 ***
#> x2            2.7063     0.3582   7.554 1.52e-12 ***
#> ---
#> Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#> 
#> ------------------------------------------------------------------
#> No. of observations in the fit:  200 
#> Degrees of Freedom for the fit:  4
#>       Residual Deg. of Freedom:  196 
#>                       at cycle:  3 
#>  
#> Global Deviance:     -109.0766 
#>             AIC:     -101.0766 
#>             SBC:     -87.88336 
#> ******************************************************************